@@ -29,11 +29,14 @@ def build_special_url_list():
     list.append('^http://server/.*')
     list.append('username:password@YOUR')
     list.append('www\.dummyurl\.com')
-
-
+    list.append('www\.example\.com')
     # clean URLs - which do not correspond to a kit i.e with a smali path
     list.append('creativecommons\.org')
     list.append('docs\.google\.')
+    list.append('support\.google\.')
+    list.append('developer\.android\.com')
+    list.append('developers\.google\.com')
+    list.append('googlesyndication\.com')
     list.append('jsoup\.org')
     list.append('www\.jcip\.net')
     list.append('finance\.google\.')
@@ -42,6 +45,7 @@ def build_special_url_list():
     list.append('https*://[a-zA-Z]*\.google\.com/') 
     list.append('www\.google\.') 
     list.append('checkout\.google\.com')
+    list.append('doubleclick\.net')
     list.append('\.google-analytics\.com') 
     list.append('^https*://[a-z]*\.googleapis\.com/')
     list.append('plus\.url\.google\.com') 
@@ -50,8 +54,11 @@ def build_special_url_list():
     list.append('material\.io')
     list.append('java\.sun\.com') 
     list.append('\.facebook\.com/help') 
-    list.append('\.facebook\.com$') 
+    list.append('\.facebook\.com$')
+    list.append('fonts\.gstatic\.com')
     list.append('forum\.xda-developers\.com/showthread\.php')
+    list.append('www\.freetype\.org')
+    list.append('www\.microsoft\.com')
     list.append('mozilla\.org') 
     list.append('www\.android\.com') 
     list.append('developer\.android\.com/reference/')
@@ -85,9 +92,11 @@ def build_special_url_list():
     list.append('github\.com')
     list.append('jquery\.org')
     list.append('www\.iana\.org')
+    list.append('stackoverflow\.com')
+    list.append('www\.unicode\.org')
+    list.append('freetype\.org')
 
-
-        # AV
+    # AV
     list.append('www\.fortinet\.com') 
     list.append('docs\.fortinet\.com/fclient/android/')
     list.append('home\.mcafee\.com')
@@ -98,7 +107,7 @@ def build_special_url_list():
     list.append('www\.trendmicro\.com') 
     list.append('https*://[a-zA-Z0-9]*\.360safe\.com')
 
-        # search engines
+    # search engines
     list.append('search\.twitter\.com') 
     list.append('search\.yahoo\.com') 
     list.append('www\.baidu\.com') 
@@ -107,7 +116,7 @@ def build_special_url_list():
     list.append('www\.searchmobileonline\.com') 
 
 
-        # XML
+    # XML
     list.append('^https*://push$') 
     list.append('^https*://schemas') 
     list.append('^https*://www\.$') 
@@ -117,7 +126,7 @@ def build_special_url_list():
     list.append('xmlpull\.org') 
     list.append('^https*://.*/configure[-_0-9]*\.dtd$')
     
-        # Operator
+    # Operator
     list.append('10\.0\.0\.172') 
     list.append('10\.0\.0\.200') 
     list.append('wap\.uni-info\.com\.cn') 
@@ -139,5 +148,3 @@ def build_special_url_list():
     list.append('^https*://.*\.alipay.com')
 
     return list
-
-        
